@@ -117,6 +117,9 @@ CategoriesComparisonChart::CategoriesComparisonChart(Budget *budg, QWidget *pare
 	themeCombo->addItem("Blue Icy", QChart::ChartThemeBlueIcy);
 	themeCombo->addItem("Qt", QChart::ChartThemeQt);
 	buttons->addWidget(themeCombo);
+	deleteButton = new QPushButton(LOAD_ICON("edit-delete"), QString(), this);
+	deleteButton->setCheckable(true);
+	buttons->addWidget(deleteButton);
 #endif
 	QButtonGroup *group = new QButtonGroup(this);
 	percentButton = new QRadioButton("%", this);
@@ -209,6 +212,7 @@ CategoriesComparisonChart::CategoriesComparisonChart(Budget *budg, QWidget *pare
 #ifdef QT_CHARTS_LIB
 	connect(themeCombo, SIGNAL(activated(int)), this, SLOT(themeChanged(int)));
 	connect(typeCombo, SIGNAL(activated(int)), this, SLOT(typeChanged(int)));
+	connect(deleteButton, SIGNAL(toggled(bool)), this, SLOT(deleteToggled(bool)));
 #endif
 	connect(sourceCombo, SIGNAL(activated(int)), this, SLOT(sourceChanged(int)));
 	connect(accountCombo, SIGNAL(selectedAccountsChanged()), this, SLOT(updateDisplay()));
@@ -242,6 +246,7 @@ void CategoriesComparisonChart::resetOptions() {
 	if(index < 0) index = 0;
 	themeCombo->setCurrentIndex(index);
 	typeCombo->setCurrentIndex(0);
+	deleteButton->setChecked(false);
 	chart->setTheme(theme >= 0 ? (QChart::ChartTheme) theme : QChart::ChartThemeBlueNcs);
 #endif
 	int value_type = settings.value("valueType", 2).toInt();
@@ -1240,7 +1245,6 @@ void CategoriesComparisonChart::updateDisplay() {
 	while((index < account_order.count()) || (current_account && index < desc_order.size())) {
 		QString legend_string;
 		double legend_value = 0.0;
-		double current_value = 0.0;
 		if(account_order.isEmpty()) {
 			if(desc_order[index].isEmpty()) {
 				legend_string = tr("No description", "Referring to the transaction description property (transaction title/generic article name)");
@@ -1259,16 +1263,15 @@ void CategoriesComparisonChart::updateDisplay() {
 		}
 		int deci = 0;
 		if(valueButton->isChecked()) {
-			legend_value = current_value;
 			if(legend_value < 100.0) deci = currency->fractionalDigits();
 		} else {
-			legend_value = (current_value * 100) / value;
+			legend_value = (legend_value * 100) / value;
 			if(legend_value < 10.0 && legend_value > -10.0) {
 				legend_value = round(legend_value * 10.0) / 10.0;
 				deci = 1;
 			}
 		}
-		QGraphicsSimpleTextItem *legend_text = new QGraphicsSimpleTextItem(QString("%1 (%2%)").arg(legend_string).arg(valueButton->isChecked() ? currency->formatValue(legend_value, deci) : budget->formatValue(legend_value, deci) + "%"));
+		QGraphicsSimpleTextItem *legend_text = new QGraphicsSimpleTextItem(QString("%1 (%2)").arg(legend_string).arg(valueButton->isChecked() ? currency->formatValue(legend_value, deci) : budget->formatValue(legend_value, deci) + "%"));
 		legend_text->setFont(legend_font);
 		legend_text->setBrush(Qt::black);
 		if(legend_text->boundingRect().width() > text_width) text_width = legend_text->boundingRect().width();
@@ -1291,30 +1294,6 @@ void CategoriesComparisonChart::updateDisplay() {
 
 	index = 0;
 	while((index < account_order.count()) || (current_account && index < desc_order.size())) {
-		QString legend_string;
-		double legend_value = 0.0;
-		if(account_order.isEmpty()) {
-			if(desc_order[index].isEmpty()) {
-				legend_string = tr("No description", "Referring to the transaction description property (transaction title/generic article name)");
-			} else {
-				legend_string = desc_map[desc_order[index]];
-			}
-			legend_value = desc_values[desc_order[index]];
-		} else {
-			account = account_order.at(index);
-			if(!account) {
-				if(type == ACCOUNT_TYPE_ASSETS) legend_string = tr("Other accounts");
-				else legend_string = tr("Other categories");
-			} else if(current_account) legend_string = account->name();
-			else legend_string = account->nameWithParent();
-			legend_value = values[account];
-		}
-		legend_value = (legend_value * 100) / value;
-		if(legend_value < 10.0 && legend_value > -10.0) {
-			legend_value = round(legend_value * 10.0) / 10.0;
-		} else {
-			legend_value = round(legend_value);
-		}
 		legend_texts[index]->setPos(legend_x + fh * 1.3, legend_y + (fh * 1.5) * index);
 		scene->addItem(legend_texts[index]);
 		index++;
@@ -1431,15 +1410,27 @@ void CategoriesComparisonChart::themeChanged(int index) {
 void CategoriesComparisonChart::typeChanged(int type) {
 	percentButton->setEnabled(type == 0);
 	valueButton->setEnabled(type == 0);
+	deleteButton->setEnabled(type == 0);
 	updateDisplay();
 }
 void CategoriesComparisonChart::sliceHovered(QPieSlice *slice, bool state) {
 	if(!slice || slice->isExploded() || slice->percentage() >= 0.08) return;
 	slice->setLabelVisible(state);
 }
+void CategoriesComparisonChart::deleteToggled(bool b) {
+	if(b) {
+		chart->setCursor(Qt::CrossCursor);
+		chart->legend()->setCursor(Qt::CrossCursor);
+	} else {
+		chart->unsetCursor();
+		chart->legend()->unsetCursor();
+	}
+}
 void CategoriesComparisonChart::sliceClicked(QPieSlice *slice) {
 	if(!slice) return;
-	if(slice->isExploded()) {
+	if(deleteButton->isChecked()) {
+		slice->series()->remove(slice);
+	} else if(slice->isExploded()) {
 		slice->setLabelVisible(slice->percentage() >= 0.08);
 		slice->setExploded(false);
 	} else {
