@@ -166,14 +166,14 @@ void Currency::writeElements(QXmlStreamWriter *xml, bool local_save) {
 		QMap<QDate, double>::const_iterator it = rates.constBegin();
 		while(it != rates.constEnd()) {
 			xml->writeStartElement("rate");
-			xml->writeAttribute("value", QString::number(it.value(), 'f', 5));
+			xml->writeAttribute("value", QString::number(it.value(), 'g', SAVE_MONETARY_PRECISION));
 			xml->writeAttribute("date", it.key().toString(Qt::ISODate));
 			xml->writeEndElement();
 			++it;
 		}
 	} else if(!rates.isEmpty()) {
 		xml->writeStartElement("rate");
-		xml->writeAttribute("value", QString::number(rates.last(), 'f', 5));
+		xml->writeAttribute("value", QString::number(rates.last(), 'g', SAVE_MONETARY_PRECISION));
 		xml->writeAttribute("date", rates.lastKey().toString(Qt::ISODate));
 		xml->writeEndElement();
 	}
@@ -241,6 +241,7 @@ double Currency::convertFrom(double value, const Currency *from_currency, const
 }
 
 QString Currency::formatValue(double value, int nr_of_decimals, bool show_currency, bool always_show_sign, bool conventional_sign_placement) const {
+	if(show_currency && !o_budget->show_default_currency && this == o_budget->defaultCurrency()) show_currency = false;
 	if(nr_of_decimals < 0) {
 		if(i_decimals < 0) nr_of_decimals = MONETARY_DECIMAL_PLACES;
 		else nr_of_decimals = i_decimals;
