@@ -1066,6 +1066,7 @@ MultiAccountTransaction *EditMultiAccountWidget::createTransaction() {
 	CategoryAccount *account = selectedCategory();
 	MultiAccountTransaction *split = new MultiAccountTransaction(budget, account, descriptionEdit->text());
 	linksWidget->updateTransaction(split);
+	if(quantityEdit) split->setQuantity(quantityEdit->value());
 	split->setComment(commentEdit->toPlainText());
 	split->setAssociatedFile(fileEdit->text());
 	tagButton->modifyTransaction(split);
@@ -1427,20 +1428,20 @@ void EditDebtPaymentWidget::openFile() {
 
 void EditDebtPaymentWidget::newAccount() {
 	accountCombo->createAccount();
-	loanCombo->updateAccounts();
+	if(loanCombo) loanCombo->updateAccounts();
 	bool b = budget->usesMultipleCurrencies();
-	paymentLabel->setVisible(b);
-	paymentEdit->setVisible(b);
+	if(paymentLabel) paymentLabel->setVisible(b);
+	if(paymentEdit) paymentEdit->setVisible(b);
 }
 void EditDebtPaymentWidget::newCategory() {
 	categoryCombo->createAccount();
 }
 void EditDebtPaymentWidget::newLoan() {
 	loanCombo->createAccount();
-	accountCombo->updateAccounts();
+	if(accountCombo) accountCombo->updateAccounts();
 	bool b = budget->usesMultipleCurrencies();
-	paymentLabel->setVisible(b);
-	paymentEdit->setVisible(b);
+	if(paymentLabel) paymentLabel->setVisible(b);
+	if(paymentEdit) paymentEdit->setVisible(b);
 }
 void EditDebtPaymentWidget::accountChanged() {
 	valueChanged();
