@@ -255,7 +255,7 @@ class Eqonomize : public QMainWindow {
 		QAction *ActionImportCSV, *ActionImportQIF, *ActionImportEQZ, *ActionExportQIF;
 		QAction *ActionConvertCurrencies, *ActionUpdateExchangeRates;
 		QAction *ActionExtraProperties, *ActionUseExchangeRateForTransactionDate, *ActionSetBudgetPeriod, *ActionSetScheduleConfirmationTime, *AIPCurrentMonth, *AIPCurrentYear, *AIPCurrentWholeMonth, *AIPCurrentWholeYear, *AIPRememberLastDates, *ABFDaily, *ABFWeekly, *ABFFortnightly, *ABFMonthly, *ABFNever, *ACSTime[11];
-		QAction *ActionSetMainCurrency, *ActionSyncSettings, *ActionSelectFont, *ActionDarkMode;
+		QAction *ActionSetMainCurrency, *ActionShowMainCurrency, *ActionSyncSettings, *ActionSelectFont, *ActionDarkMode;
 		QActionGroup *ActionSelectInitialPeriod, *ActionSelectBackupFrequency, *ActionSelectLang;
 		QAction *ActionHelp, *ActionWhatsThis, *ActionReportBug, *ActionAbout, *ActionAboutQt;
 		QAction *ActionNewTag, *ActionRenameTag, *ActionRemoveTag;
@@ -411,6 +411,7 @@ class Eqonomize : public QMainWindow {
 		void currenciesModified();
 		void warnAndAskForExchangeRate();
 		void setMainCurrency();
+		void showMainCurrency(bool);
 		void setMainCurrencyIndexChanged(int index);
 		void updateUsesMultipleCurrencies();
 		void openCurrencyConversion();
