@@ -66,7 +66,7 @@ class TransactionFilterWidget : public QWidget {
 		void focusFirst();
 		void updateTags();
 
-		void setFilter(QDate fromdate, QDate todate, double min = -1.0, double max = -1.0, Account *from_account = NULL, Account *to_account = NULL, QString description = QString(), QString payee = QString(), bool exclude = false, bool exact_match = false, bool exclude_subs = false);
+		void setFilter(QDate fromdate, QDate todate, double min = -1.0, double max = -1.0, Account *from_account = NULL, Account *to_account = NULL, QString description = QString(), QString payee = QString(), bool exclude = false, bool exact_match = false, bool exclude_subs = false, bool duplicates = false);
 
 	protected:
 
@@ -81,7 +81,7 @@ class TransactionFilterWidget : public QWidget {
 		QLineEdit *descriptionEdit;
 		QDate from_date, to_date;
 		QRadioButton *includeButton, *excludeButton;
-		QCheckBox *exactMatchButton, *excludeSubsButton;
+		QCheckBox *exactMatchButton, *excludeSubsButton, *duplicatesButton;
 		QPushButton *clearButton;
 		QButtonGroup *group;
 
